@@ -1,24 +1,5 @@
 #! /usr/bin/env perl
 
-# Generate a release announcement message.
-
-# Copyright (C) 2007-2020 Free Software Foundation, Inc.
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <https://www.gnu.org/licenses/>.
-#
-# Written by Akimn Demaille.
-
 use warnings;
 use 5.005;
 use strict;
@@ -31,7 +12,7 @@ while (<STDIN>)
 {
     if (/^\s*             # Initial spaces.
         (?:(-\w),\s+)?    # $1: $short: Possible short option.
-        (--[-\w]+)        # $2: $long:  Mandatory long option.
+        (--[-\w]+)        # $2: $long:  Long option.
         (\[?)             # $3: $opt:   '[' iff the argument is optional.
         (?:=(\S+))?       # $4: $arg:   Possible argument name.
         \s                # Spaces.
@@ -51,6 +32,7 @@ while (<STDIN>)
             # if $opt, $arg contains the closing ].
             substr ($arg, -1) = ''
                 if $opt eq '[';
+            $arg =~ s/^=//;
             $arg = lc ($arg);
             my $dir_arg = $arg;
             # If the argument is complete (e.g., for --define[=NAME[=VALUE]]),
@@ -66,11 +48,7 @@ while (<STDIN>)
             # are strings and have the same syntax as on the command line.
             if ($dir_arg eq 'name[=value]')
             {
-                # -D/-F do not add quotes to the argument.
-                $dir_arg =
-                    $dir eq "%define"
-                    ? '@var{name} [@var{value}]'
-                    : '@var{name} ["@var{value}"]';
+                $dir_arg = '@var{name} ["@var{value}"]';
             }
             else
             {
@@ -90,15 +68,12 @@ while (<STDIN>)
 my $sep = '';
 foreach my $long (sort keys %option)
 {
-    # Couldn't find a means to escape @ in the format (for @item, @tab), so
-    # pass it as a literal to print.
-format STDOUT =
-@item @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< @tab @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< @tab @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
-{
-  '@', '@option{' . $long . '}',
-  '@', $option{$long} ? ('@option{' . $option{$long} . '}') : '',
-  '@', $directive{$long} ? ('@code{' . $directive{$long} . '}') : ''
-}
-.
-    write;
+    # Avoid trailing spaces.
+    print $sep;
+    $sep = "\n";
+    print '@item @option{', $long, "}\n\@tab";
+    print ' @option{', $option{$long}, '}' if $option{$long};
+    print "\n\@tab";
+    print ' @code{', $directive{$long}, '}' if $directive{$long};
+    print "\n";
 }
