@@ -1,6 +1,7 @@
 /* Functions to support bitset statistics.
 
-   Copyright (C) 2002-2004, 2009-2015 Free Software Foundation, Inc.
+   Copyright (C) 2002-2004, 2009-2015, 2018 Free Software Foundation,
+   Inc.
 
    Contributed by Michael Hayes (m.hayes@elec.canterbury.ac.nz).
 
@@ -24,10 +25,10 @@
 
 extern bool bitset_stats_enabled;
 
-extern enum bitset_type bitset_stats_type_get (bitset);
+enum bitset_type bitset_stats_type_get (bitset);
 
-extern size_t bitset_stats_bytes (void);
+size_t bitset_stats_bytes (void);
 
-extern bitset bitset_stats_init (bitset, bitset_bindex, enum bitset_type);
+bitset bitset_stats_init (bitset, bitset_bindex, enum bitset_type);
 
 #endif
